==> jc-1.4.0.tar.gz: java/awt/PageAttributes__24OriginType.h <==
// public final class java.awt.PageAttributes$OriginType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 487fa65127c10484 java_awt_PageAttributes__24OriginType
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_PageAttributes__24OriginType_H_
#define _JC_java_awt_PageAttributes__24OriginType_H_

// Forward structure declarations
struct _jc_java_awt_PageAttributes__24OriginType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PageAttributes__24OriginType$sub_refs	_jc_java_awt_PageAttributes__24OriginType$sub_refs;
typedef struct _jc_java_awt_PageAttributes__24OriginType$sub_nonrefs	_jc_java_awt_PageAttributes__24OriginType$sub_nonrefs;
typedef struct _jc_java_awt_PageAttributes__24OriginType$refs	_jc_java_awt_PageAttributes__24OriginType$refs;
typedef struct _jc_java_awt_PageAttributes__24OriginType$nonrefs	_jc_java_awt_PageAttributes__24OriginType$nonrefs;
typedef struct _jc_java_awt_PageAttributes__24OriginType$object	_jc_java_awt_PageAttributes__24OriginType$object;

typedef struct _jc_java_awt_PageAttributes__24OriginType$fields_struct	_jc_java_awt_PageAttributes__24OriginType$fields_struct;
typedef const struct _jc_java_awt_PageAttributes__24OriginType$vmethods	_jc_java_awt_PageAttributes__24OriginType$vmethods;
typedef const struct _jc_java_awt_PageAttributes__24OriginType$vtable	_jc_java_awt_PageAttributes__24OriginType$vtable;
typedef const struct _jc_java_awt_PageAttributes__24OriginType$vtype	_jc_java_awt_PageAttributes__24OriginType$vtype;

// Class fields structure
struct _jc_java_awt_PageAttributes__24OriginType$fields_struct {
	_jc_object_array	*NAMES;
	struct _jc_java_awt_PageAttributes__24OriginType$object	*PHYSICAL;
	struct _jc_java_awt_PageAttributes__24OriginType$object	*PRINTABLE;
};
extern _jc_java_awt_PageAttributes__24OriginType$fields_struct _jc_java_awt_PageAttributes__24OriginType$class_fields;

// Constructors
extern void _jc_java_awt_PageAttributes__24OriginType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_PageAttributes__24OriginType$object *, jint);

// Static methods
extern void _jc_java_awt_PageAttributes__24OriginType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_PageAttributes__24OriginType$vmethods {
};

// Vtable
struct _jc_java_awt_PageAttributes__24OriginType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_PageAttributes__24OriginType$vmethods	java_awt_PageAttributes__24OriginType;
};

// Vtype
struct _jc_java_awt_PageAttributes__24OriginType$vtype {
	_jc_type			type;
	_jc_java_awt_PageAttributes__24OriginType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24OriginType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PageAttributes__24OriginType$refs {
    _jc_java_awt_PageAttributes__24OriginType$sub_refs	java_awt_PageAttributes__24OriginType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24OriginType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PageAttributes__24OriginType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_PageAttributes__24OriginType$sub_nonrefs	java_awt_PageAttributes__24OriginType;
};

// Object instance structure
struct _jc_java_awt_PageAttributes__24OriginType$object {
	_jc_java_awt_PageAttributes__24OriginType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PageAttributes__24OriginType$vtype	*vtype;
	_jc_java_awt_PageAttributes__24OriginType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PageAttributes__24OriginType$vtype _jc_java_awt_PageAttributes__24OriginType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PageAttributes__24OriginType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PageAttributes__24OriginType$class_object;

#endif	/* _JC_java_awt_PageAttributes__24OriginType_H_ */

==> jc-1.4.6.tar.gz: java/awt/PageAttributes__24OriginType.h <==
// public final class java.awt.PageAttributes$OriginType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 487fa65127c10484 java_awt_PageAttributes__24OriginType
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_PageAttributes__24OriginType_H_
#define _JC_java_awt_PageAttributes__24OriginType_H_

// Forward structure declarations
struct _jc_java_awt_PageAttributes__24OriginType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PageAttributes__24OriginType$sub_refs	_jc_java_awt_PageAttributes__24OriginType$sub_refs;
typedef struct _jc_java_awt_PageAttributes__24OriginType$sub_nonrefs	_jc_java_awt_PageAttributes__24OriginType$sub_nonrefs;
typedef struct _jc_java_awt_PageAttributes__24OriginType$refs	_jc_java_awt_PageAttributes__24OriginType$refs;
typedef struct _jc_java_awt_PageAttributes__24OriginType$nonrefs	_jc_java_awt_PageAttributes__24OriginType$nonrefs;
typedef struct _jc_java_awt_PageAttributes__24OriginType$object	_jc_java_awt_PageAttributes__24OriginType$object;

typedef struct _jc_java_awt_PageAttributes__24OriginType$fields_struct	_jc_java_awt_PageAttributes__24OriginType$fields_struct;
typedef const struct _jc_java_awt_PageAttributes__24OriginType$vmethods	_jc_java_awt_PageAttributes__24OriginType$vmethods;
typedef const struct _jc_java_awt_PageAttributes__24OriginType$vtable	_jc_java_awt_PageAttributes__24OriginType$vtable;
typedef const struct _jc_java_awt_PageAttributes__24OriginType$vtype	_jc_java_awt_PageAttributes__24OriginType$vtype;

// Class fields structure
struct _jc_java_awt_PageAttributes__24OriginType$fields_struct {
	_jc_object_array	*NAMES;
	struct _jc_java_awt_PageAttributes__24OriginType$object	*PHYSICAL;
	struct _jc_java_awt_PageAttributes__24OriginType$object	*PRINTABLE;
};
extern _jc_java_awt_PageAttributes__24OriginType$fields_struct _jc_java_awt_PageAttributes__24OriginType$class_fields;

// Constructors
extern void _jc_java_awt_PageAttributes__24OriginType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_PageAttributes__24OriginType$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_PageAttributes__24OriginType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_PageAttributes__24OriginType$vmethods {
};

// Vtable
struct _jc_java_awt_PageAttributes__24OriginType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_PageAttributes__24OriginType$vmethods	java_awt_PageAttributes__24OriginType;
};

// Vtype
struct _jc_java_awt_PageAttributes__24OriginType$vtype {
	_jc_type			type;
	_jc_java_awt_PageAttributes__24OriginType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24OriginType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PageAttributes__24OriginType$refs {
    _jc_java_awt_PageAttributes__24OriginType$sub_refs	java_awt_PageAttributes__24OriginType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24OriginType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PageAttributes__24OriginType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_PageAttributes__24OriginType$sub_nonrefs	java_awt_PageAttributes__24OriginType;
};

// Object instance structure
struct _jc_java_awt_PageAttributes__24OriginType$object {
	_jc_java_awt_PageAttributes__24OriginType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PageAttributes__24OriginType$vtype	*vtype;
	_jc_java_awt_PageAttributes__24OriginType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PageAttributes__24OriginType$vtype _jc_java_awt_PageAttributes__24OriginType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PageAttributes__24OriginType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PageAttributes__24OriginType$class_object;

#endif	/* _JC_java_awt_PageAttributes__24OriginType_H_ */
